from sys import stdout

import pygame

import gummworld2
from gummworld2 import State, Vec2d
from gummworld2 import geometry

import tools


class Player(geometry.RectGeometry):
    
    def __init__(self, position):
        super(Player, self).__init__(0,0, 16,32, position)
        self.image = pygame.Surface(self.rect.size)
        self.image.fill(pygame.Color('pink'), (0,0,16,16))
        self.image.fill(pygame.Color('black'), (0,16,16,16))
        
        self.tools = [
            tools.MiningPick(self),
            tools.JackHammer(self),
        ]
        self.tool = self.tools[0]
        
        self.velocity = Vec2d(0.0, 0.0)
        self.jump_speed = 0
        self.jumping = False
        self.foot_rect = pygame.Rect(self.rect)
    
    @property
    def _free_fall(self):
#        return self.velocity.y + self.fall_sec * 9.6
        return 9.8 * self.fall_sec**2
    
    def update(self, dt):
        if self.tool:
            self.tool.update(dt)
        
        dx,dy = self.velocity
        if dx:
            self._move(dx, 0)
        if dy:
            self._move(0, dy)
        if self.jumping:
            self._move(0, dy)
            if self.jumping:
                self.velocity.y += 9.8 * dt
            if self.velocity.y > State.speed * 2:
                self.velocity.y = State.speed * 2
        else:
            self.foot_rect.center = self.rect.center
            self.foot_rect.y += 1
            if not State.map.collidesolids(self.foot_rect):
                self.velocity.y = 1
                self.jumping = True
    
    def _move(self, dx, dy):
        save = self.position
        self.position += (dx,dy)
        for tile in State.map.collidesolids(self.rect):
#            if dx:
#                self._bump_respond(dx, dy, tile)
#            else:
#                self._bump_respond(dx, dy, tile)
            self._bump_respond(dx, dy, tile)
        self.position = self.rect.center
    
    def _bump_respond(self, dx, dy, tile):
        if dx > 0:
            correct = self.rect.right - tile.rect.left
            self.position -= (correct,0)
            self.velocity.x = 0.0
        elif dx < 0:
            correct = tile.rect.right - self.rect.left
            self.position += (correct,0)
            self.velocity.x = 0.0
        if dy > 0:
            correct = self.rect.bottom - tile.rect.top
            self.position -= (0,correct)
            self.velocity.y = 0.0
            self.jumping = False
        elif dy < 0:
            correct = tile.rect.bottom - self.rect.top
            self.position += (0,correct)
            self.velocity.y = 0.0
            self.jumping = False
    
    def use_tool(self):
        if self.tool_ready():
            self.tool_cooldown = self.tool_cost
            return self.tool
        else:
            return 0
    
    def tool_ready(self):
        return self.tool_cooldown <= 0.0
    
    def next_tool(self):
        try:
            i = self.tools.index(self.tool)
        except:
            i = 0
        try:
            self.tool = self.tools[i+1]
        except:
            self.tool = self.tools[0]
    
    def jump(self):
        if not self.jumping:
            self.velocity.y = -(32 / 9.8)
            self.jumping = True
