__doc__ = """Game logic"""


from gummworld2 import State

import terrainnodes


# deformed nodes that will eventually reset if they are not completely
# defeated.
class ResetBin(object):
    def __init__(self):
        self.things = []
    def add(self, thing):
        if thing not in self.things:
            self.things.append(thing)
    def remove(self, thing):
        if thing in self.things:
            self.things.remove(thing)
    def update(self, dt):
        for thing in self.things[:]:
            thing.heal(dt)
            if thing.health == thing.max_health:
                self.remove(thing)
                State.renderer.set_dirty(thing.rect)
reset_bin = ResetBin()


def update(dt):
    game = State.game
    player = game.player
    
    player.velocity.x = game.movex * game.sprint
    player.update(dt)
    if game.mouse_down_1:
        action_mouse_button_1(game.mouse_down_1)
    elif game.mouse_down_3:
        action_mouse_button_3(game.mouse_down_3)
    
    reset_bin.update(dt)


def action_mouse_button_1(pos):
    if not pos:
        return
    
    pos = State.camera.screen_to_world(pos)
    player = State.game.player
    tool = player.tool
    if pos:
        tool.fire(pos)
    if tool.is_ready():
        map_ = State.map
        terrain = map_.layers[0].objects
        objects_in_range = terrain.intersect_objects(tool.rect)
        for obj in objects_in_range:
            if obj.deformable and obj.rect.collidepoint(pos):
                damage = tool.use()
                obj.hit(damage)
                if obj.dirty:
                    obj.dirty = False  # refreshes timer on reset bin
                    State.renderer.set_dirty(obj.rect)
                if obj.health <= 0.0:
                    terrain.remove(obj)
                    reset_bin.remove(obj)
                    repl = terrainnodes.Air(position=obj.position)
                    terrain.add(repl)
                    State.renderer.set_dirty(obj.rect)
                else:
                    reset_bin.add(obj)


def action_mouse_button_3(pos):
    if not pos:
        return
    
    pos = State.camera.screen_to_world(pos)
    player = State.game.player
    map_ = State.map
    terrain = map_.layers[0].objects
    cell_id = terrain.index_at(*pos)
    cell = terrain.get_cell(cell_id)
    for obj in cell:
        if obj.rect.collidepoint(pos):
            if terrainnodes.issolid(obj):
                return
            else:
                break
    
    # obj is the match after the loop exits
    new = terrainnodes.Dirt(obj.position)
    if new.rect.colliderect(player.rect):
        return
    terrain.remove(obj)
    terrain.add(new)
    State.renderer.set_dirty(obj.rect)
