import pygame

import terrainnodes


class _MiningTool(object):
    
    name = 'Mining Tool'
    
    rect_anchor = 'center'
    cost = 1.0         # cooldown in secs
    power = 1.0        # points of power per use
    
    def __init__(self, actor):
        # actor can be the player or other character that mines
        self.actor = actor
        tw,th = terrainnodes.NODE_SIZE()
        self.rect = pygame.Rect(actor.rect).inflate(int(tw*3.25), int(th*3.25))
        
        self.cooldown = 0.0     # secs
        self._fire = False      # the primary action has been activated
        self.target = None
        
        self.draw_hitbox = False    # See Game.draw()
    
    def _set_pos(self, val):
        x = int(round(val[0]))
        y = int(round(val[1]))
        setattr(self.rect, self.rect_anchor, (x,y))
    def _get_pos(self):
        return getattr(self.rect, self.rect_anchor)
    position = property(_get_pos, _set_pos, "Get and set the rect attribute named by self.rect_anchor")
    
    def fire(self, pos):
        if not self._fire:
            self.cooldown = self.cost
        self._fire = True
        self.target = pos
    
    def is_ready(self):
        return self._fire and self.cooldown <= 0.0
    
    def use(self):
        if self.is_ready():
            self._fire = False
            return self.power
        else:
            return 0.0
    
    def pct_cooldown(self):
        return self.cost / self.cooldown
    
    def update(self, dt):
        if self.cooldown > 0.0:
            self.cooldown -= dt
        self.position = self.actor.position


class MiningPick(_MiningTool):
    
    name = 'Mining Pick'
    
    cost = 0.75        # cooldown in secs
    power = 1.0        # points of power per use


class JackHammer(_MiningTool):
    
    name = 'Jack Hammer'
    
    cost = 0.05
    power = 2.0
